Documentation
¶
Overview ¶
Package chef provides resources for configuring a chef client.rb file
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BuildConfig ¶
BuildConfig takes settings and returns a client.rb
func CheckChefInstall ¶
CheckChefInstall will return true/false if chef is installed
func InstallChef ¶
InstallChef will check to see if chef needs to be installed and if so install using the appropriate options per platform
func WriteFiles ¶
WriteFiles writes required config files to disk
Types ¶
type Settings ¶
type Settings struct {
LogLevel string
LogLocation string
ValidationClientName string
ValidationKey string
ChefServerURL string
JSONAttribs string
SSLVerifyMode string
LocalKeyGeneration bool
RestTimeout int
HTTPRetryCount int
NoLazyLoad bool
OhaiDirectory string
OhaiDisabledPlugins []string
NodeName string
}
Settings contains the client.rb settings
Click to show internal directories.
Click to hide internal directories.